@@ -27,7 +27,10 @@ from .selecting import (
     reject_falsy,
     take_after_last_match,
     take_after_inclusive,
+    take_before_exclusive,
     take_before_inclusive,
+    take_until_exclusive,
+    take_until_inclusive,
     take_between_inclusive,
     take_between_inclusive_values,
     skip_while,
@@ -67,7 +70,10 @@ __all__ = [
     "separate_with",
     "take_after_inclusive",
     "take_after_last_match",
+    "take_before_exclusive",
     "take_before_inclusive",
+    "take_until_exclusive",
+    "take_until_inclusive",
     "take_between_inclusive",
     "take_between_inclusive_values",
     "skip_while",
